FunDspGenerator

Struct FunDspGenerator 

pub struct FunDspGenerator { /* private fields */ }
Available on crate feature fundsp only.
A polyphonic generator using FunDSP audio units created from a factory function.

The factory function receives shared variables for gate, frequency, volume, panning and optional user defined shared parameters to control playback, and returns a FunDSP audio unit that uses these as variables.

Example

use phonic::{GeneratorPlaybackOptions, generators::FunDspGenerator};
use phonic::fundsp::prelude32::*;

// Simple fundsp generator without additional parameters
let generator = FunDspGenerator::new(
    "example_synth",
    |gate: Shared, freq: Shared, vol: Shared, pan: Shared| {
        // Simple saw wave with envelope and panning
        let envelope = var(&gate) >> follow(0.01);
        let sound = var(&freq) >> saw();
        Box::new((envelope * sound * var(&vol) | var(&pan)) >> panner())
    },
    GeneratorPlaybackOptions::default(), // default playback options
    44100,  // voice and source's sample rate
);

Implementations

Source

impl FunDspGenerator

pub fn new<S: AsRef<str>, F>( synth_name: S, voice_factory: F, options: GeneratorPlaybackOptions, output_sample_rate: u32, ) -> Result<Self, Error>
where F: Fn(Shared, Shared, Shared, Shared) -> Box<dyn AudioUnit>,

Create a new FunDSP-based generator with the given voice count.

Arguments
  • synth_name - A name for the synth (for playback status tracking and debugging).
  • voice_factory - Function that creates a voice unit with given (frequency, volume, gate, panning) shared variables.
  • options - Generic generator playback options.
  • sample_rate - Output sample rate.
pub fn with_parameters<S: AsRef<str>, F>( synth_name: S, parameters: &[&dyn Parameter], parameter_state: Option<&[(FourCC, ParameterValueUpdate)]>, modulation_config: ModulationConfig, voice_factory: F, options: GeneratorPlaybackOptions, output_sample_rate: u32, ) -> Result<Self, Error>
where F: Fn(Shared, Shared, Shared, Shared, &mut dyn FnMut(FourCC) -> Shared, &mut dyn FnMut(FourCC) -> SharedBuffer) -> Box<dyn AudioUnit>,

Create a new FunDSP-based generator with shared parameters and optional modulation.

Arguments
  • synth_name - A name for the synth (for playback status tracking and debugging).
  • parameters - A slice of parameters which will be passed to the factory.
  • parameter_state - Optional parameter values that should be applied initially.
  • modulation_config - Configuration for modulation sources and targets.
  • voice_factory - Function that creates a voice unit with given shared variables, parameter accessor, and modulation buffer accessor.
  • options - Generic generator playback options.
  • sample_rate - Output sample rate.