PreloadedFileSource

Struct PreloadedFileSource 

pub struct PreloadedFileSource { /* private fields */ }
A buffered, clonable FileSource, which decodes the entire file into a buffer before its played back.

Buffers of preloaded file sources are shared (wrapped in an Arc), so cloning a source is very cheap as this only copies a buffer reference and not the buffer itself. This way a file can be pre-loaded once and can then be cloned and reused as often as necessary.

Implementations

Source

impl PreloadedFileSource

pub fn from_file<P: AsRef<Path>>( path: P, options: FilePlaybackOptions, output_sample_rate: u32, ) -> Result<Self, Error>

Create a new preloaded file source with the given audio file path.

pub fn from_file_buffer( file_buffer: Vec<u8>, file_path: &str, options: FilePlaybackOptions, output_sample_rate: u32, ) -> Result<Self, Error>

Create a new preloaded file source with the given raw encoded file stream buffer.

pub fn from_shared_buffer( file_buffer: Arc<AudioFileBuffer>, file_path: &str, options: FilePlaybackOptions, output_sample_rate: u32, ) -> Result<Self, Error>

Create a new preloaded file source from the given shared, decoded file buffer.

pub fn clone( &self, options: FilePlaybackOptions, output_sample_rate: u32, ) -> Result<Self, Error>

Create a copy of this preloaded source with the given playback options.

pub fn file_buffer(&self) -> Arc<AudioFileBuffer>

Access to the shared file buffer.

pub fn seek(&mut self, position: Duration)

Set a new playback position for this source.

pub fn loop_range(&self) -> Option<Range<u64>>

Returns the active loop range in sample frames: the override if set, else the file’s embedded loop range. Returns None when neither is set.

pub fn set_loop_range(&mut self, range: Option<Range<u64>>)

Override the file’s embedded loop range with a custom one. Pass None to revert to the file’s embedded loop range.

pub fn set_repeat(&mut self, repeat_count: usize)

Override the file’s playback option repeat settings with the given ones. Set to 0 to disable looping, usize::MAX to repeat forever.

pub fn set_speed(&mut self, speed: f64, glide: Option<f32>)

Set the playback speed (pitch) for this source.

pub fn stop(&mut self)

Stop the file source, starting to fade-out, when a fadeout is set, stop immediately.

pub fn reset(&mut self)

Reset the file to start playback from the beginning.

pub fn kill(&mut self)

Abruptly stop the source without applying fade-outs