pub trait SynthSourceGenerator {
// Required methods
fn is_exhausted(&self) -> bool;
fn channel_count(&self) -> usize;
fn generate(&mut self, output: &mut [f32]) -> usize;
}Expand description
A generic sample generator for SynthSourceImpl.
Required Methods
Sourcefn is_exhausted(&self) -> bool
fn is_exhausted(&self) -> bool
Returns true when output is silent oan no more generate calls are required.
Sourcefn channel_count(&self) -> usize
fn channel_count(&self) -> usize
The generator produces sample frames with this number of channels.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".