FilePlaybackHandle

Struct FilePlaybackHandle 

pub struct FilePlaybackHandle { /* private fields */ }
Query and change runtime playback properties of a playing FileSource.

Handles are Send and Sync so they can be sent across threads.

To track detailed playback status use a PlaybackStatusEvent sync_channel in the Player.

Implementations

Source

impl FilePlaybackHandle

pub fn id(&self) -> PlaybackId

Get the playback ID of this source.

pub fn is_playing(&self) -> bool

Check if this source is still playing.

pub fn cpu_load(&self) -> Option<CpuLoad>

Get the CPU load data for this source.

Returns None if CPU measurement was not enabled for this source, or if the measurement is not available at this time.

pub fn stop<T: Into<Option<u64>>>(&self, stop_time: T) -> Result<(), Error>

Stop this source at the given sample time or immediately.

pub fn seek<T: Into<Option<u64>>>( &self, position: Duration, sample_time: T, ) -> Result<(), Error>

Change playback position of the source at a specific sample time or immediately.

pub fn set_speed<T: Into<Option<u64>>>( &self, speed: f64, glide: Option<f32>, sample_time: T, ) -> Result<(), Error>

Set file source’s speed at a given sample time in future or immediately, with the given optional glide rate in semitones per second.

pub fn set_volume<T: Into<Option<u64>>>( &self, volume: f32, sample_time: T, ) -> Result<(), Error>

Set source’s volume at a given sample time in future or immediately.

pub fn set_panning<T: Into<Option<u64>>>( &self, panning: f32, sample_time: T, ) -> Result<(), Error>

Set source’s panning at a given sample time in future or immediately.