pub struct Eq5Effect { /* private fields */ }Expand description
Multi-channel 5-band parametric equalizer.
First band is using a low-shelf filter, last band a high shelf filter, the other bands are notch filters with configurable band width.
Implementations
Sourceimpl Eq5Effect
impl Eq5Effect
pub const EFFECT_NAME: &str = "Eq5"
pub const GAINS: [FloatParameter; 5]
pub const FREQUENCIES: [FloatParameter; 5]
pub const BANDWIDTHS: [FloatParameter; 5]