pub struct CpalOutput { /* private fields */ }Available on crate feature
cpal-output only.Expand description
Audio output device impl using cpal.
Implementations
Sourceimpl CpalOutput
impl CpalOutput
Sourcepub fn open() -> Result<Self, Error>
pub fn open() -> Result<Self, Error>
Open an audio output device using the default configuration.
Sourcepub fn open_with_config(config: CpalOutputConfig) -> Result<Self, Error>
pub fn open_with_config(config: CpalOutputConfig) -> Result<Self, Error>
Open an audio output device using the given configuration.
Use CpalOutput::available_drivers, CpalOutput::available_devices and
CpalOutput::supported_sample_rates to enumerate available options dynamically.
Sourcepub fn available_drivers() -> Vec<CpalOutputDeviceDriver>
pub fn available_drivers() -> Vec<CpalOutputDeviceDriver>
Returns all audio drivers available on this platform.
Always includes CpalOutputDeviceDriver::Default, followed by any named drivers that are
currently available (e.g. ASIO, WASAPI on Windows; ALSA, JACK on Linux).
Sourcepub fn available_devices(
driver: CpalOutputDeviceDriver,
) -> Result<Vec<(DeviceId, String)>, Error>
pub fn available_devices( driver: CpalOutputDeviceDriver, ) -> Result<Vec<(DeviceId, String)>, Error>
Returns (id, name)s of all output devices available for the given driver.
Sourcepub fn supported_sample_rates(
driver: CpalOutputDeviceDriver,
device_id: Option<CpalDeviceId>,
) -> Result<Vec<u32>, Error>
pub fn supported_sample_rates( driver: CpalOutputDeviceDriver, device_id: Option<CpalDeviceId>, ) -> Result<Vec<u32>, Error>
Returns unique sample rates supported by an output device, sorted ascending.
Pass device_name = None to query the driver’s default device.