Provides utilities for converting between planar and interleaved audio buffers, SIMD-accelerated buffer operations, and safe abstractions for working with interleaved audio data.
Structs
- Temp
Buffer - A preallocated buffer slice with persistent start/end positions and helper functions.
Traits
- Interleaved
Buffer - Provides safe and efficient methods to access interleaved audio data, such as iterating over
frames or individual channels, without needing to perform manual index calculations.
It is implemented for common buffer types like
&[f32]andVec<f32>. - Interleaved
Buffer Mut - Extends
InterleavedBufferwith methods for modifying the buffer’s contents. It provides safe and efficient ways to get mutable access to frames or individual channels.
Functions
- add_
buffers - Dest += Source
- add_
buffers_ with_ simd - Dest += Source
- clear_
buffer - Dest = 0.0
- clear_
buffer_ with_ simd - Dest = 0.0
- copy_
buffers - Dest = Source
- copy_
buffers_ with_ simd - Dest = Source
- interleaved_
to_ planar - Copy the given interleaved buffer into a planar one. The planar buffer’s layout defines layout of the interleaved buffer (channel and frame count). The interleaved buffer must be large enough to fill the planar buffer.
- max_
abs_ sample - Find the maximum absolute value in a buffer using SIMD
- max_
abs_ sample_ with_ simd - Find the maximum absolute value in a buffer using SIMD
- planar_
to_ interleaved - Copy the given planar buffer into an interleaved one. The planar buffer’s layout defines layout of the interleaved buffer (channel and frame count). The interleaved buffer must be large enough to fit the planar buffer.
- remap_
buffer_ channels - Remaps interleaved audio between channel layouts.
- scale_
buffer - Dest *= Value
- scale_
buffer_ with_ simd - Dest *= Value